/*
 * (C) Copyright 2000, 2001, 2002
 * Wolfgang Denk, DENX Software Engineering, wd@denx.de.
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*
 * board/config.h - configuration options, board specific
 */

/*
 * U-Boot port on EP852 board
 */

#ifndef __CONFIG_H
#define __CONFIG_H

#define	EP852_133MHz

/*
 * High Level Configuration Options
 * (easy to change)
 */

#define CONFIG_MPC852           1
#define CONFIG_EP852		1

#undef	CONFIG_WATCHDOG			/* watchdog disabled		*/


/*
 * Ethernet Settings
 */

/* Define CONFIG_FEC_ENET to use Fast ethernet instead of ethernet on SCC1 */
#define CONFIG_FEC_ENET
#ifdef CONFIG_FEC_ENET
  #define CFG_DISCOVER_PHY        1
  #define CONFIG_MII              1
#endif /* CONFIG_FEC_ENET */

#ifndef CONFIG_NET_MULTI
  #define CONFIG_NET_MULTI
#endif

#define CFG_VXWORKS_MAC_PTR 	0x4300 	/*Pass Ethernet Address to VxWorks */

#define CONFIG_BOOTP_MASK	(CONFIG_BOOTP_DEFAULT | CONFIG_BOOTP_BOOTFILESIZE)

/* undefine ethernet on SCC; currently no support for SCC ethernet */
#undef CONFIG_SCC_ENET


/*
 * Automatic Boot settings and environmental variables
 */

#if 1
  #define CONFIG_BOOTDELAY	-1		/* autoboot disabled		*/
#else
  #define CONFIG_BOOTDELAY	5		/* autoboot after 5 seconds	*/
#endif

#define CONFIG_BOARD_TYPES	1		/* support board types		*/

#undef	CONFIG_BOOTARGS
#define  CONFIG_BOOTCOMMAND							\
	"tftpboot; " 								\
	"setenv bootargs root=/dev/nfs rw nfsroot=$(serverip):$(rootpath) " 	\
	"ip=$(ipaddr):$(serverip):$(gatewayip):$(netmask):$(hostname)::off; " 	\
	"bootm"	
#define CONFIG_EXTRA_ENV_SETTINGS \
	"bootdelay=-1\0"


/*
 * Serial and Console Settings
 */

#define	CONFIG_8xx_CONS_SMC1	1	/* Console is on SMC1		*/
#undef	CONFIG_8xx_CONS_SMC2
#undef	CONFIG_8xx_CONS_NONE
#define CONFIG_BAUDRATE		9600	/* console baudrate = 9600bps	*/

#define CONFIG_LOADS_ECHO	1		/* echo on for serial download	*/
#undef	CFG_LOADS_BAUD_CHANGE			/* don't allow baudrate change	*/
#define CFG_BAUDRATE_TABLE	{ 9600, 19200, 38400, 57600, 115200 }

/*
 * Configuration Commands
 */

#define CONFIG_COMMANDS	(CFG_CMD_ALL & ~CFG_CMD_NONSTD | CFG_CMD_ELF )

/* this must be included AFTER the definition of CONFIG_COMMANDS (if any) */
#include <cmd_confdefs.h>

/* Define to allow the user to overwrite serial and ethaddr */
#define CONFIG_ENV_OVERWRITE

#define CONFIG_ETHADDR	00:10:EC:00:2C:A2
#define CONFIG_IPADDR	10.0.0.233
#define CONFIG_SERVERIP	10.0.0.36


/*
 * CPU, Clock, and Miscellaneous Settings
 */

#define	CONFIG_CLOCKS_IN_MHZ	1		/* clocks passsed to Linux in MHz */

#define CFG_852_OSCCLK		10000000	/*  10 MHz - PLL input clock		*/
#define CFG_852_CPUCLK_MIN	15000000	/*  15 MHz - CPU minimum clock		*/
#define CFG_852_CPUCLK_MAX	130000000	/* 133 MHz - CPU maximum clock		*/
#define CFG_852_CPUCLK_DEFAULT	50000000	/*  50 MHz - CPU default clock		*/
#define CONFIG_8xx_GCLK_FREQ	130000000       /* MPC860T runs at 50MHz */

						/* (it will be used if there is no	*/
						/* 'cpuclk' variable with valid value)	*/

#define CFG_MEASURE_CPUCLK			/* Measure real cpu clock	*/
						/* (function measure_gclk()	*/
						/* will be called)		*/
#ifdef CFG_MEASURE_CPUCLK
  #define CFG_8XX_XIN		10000000	/* measure_gclk() needs this	*/
#endif

#define CFG_RESET_ADDRESS	0x80000000

#define	CFG_LONGHELP				/* undef to save memory		*/

#define	CFG_PROMPT		"=> "		/* Monitor Command Prompt	*/

#if (CONFIG_COMMANDS & CFG_CMD_KGDB)
  #define  CFG_CBSIZE		1024		/* Console I/O Buffer Size	*/
#else
  #define  CFG_CBSIZE		256		/* Console I/O Buffer Size	*/
#endif

#define	CFG_PBSIZE \
	  (CFG_CBSIZE+sizeof(CFG_PROMPT)+16) 	/* Print Buffer Size */
#define	CFG_MAXARGS		16		/* max number of command args	*/
#define CFG_BARGSIZE CFG_CBSIZE			/* Boot Argument Buffer Size	*/

#define CFG_MEMTEST_START	0x0040000	/* memtest works on	*/
#define CFG_MEMTEST_END		0x00C0000	/* 4 ... 12 MB in DRAM	*/

#define	CFG_LOAD_ADDR		0x100000	/* default load address	*/

#define	CFG_HZ			1000		/* decrementer freq: 1 ms ticks	*/


/*
 * Low Level Configuration Settings
 * (address mappings, register initial values, etc.)
 * You should know what you are doing if you make changes here.
 */
/*-----------------------------------------------------------------------
 * Internal Memory Mapped Register
 */
#define CFG_IMMR		0xFA200000

/*-----------------------------------------------------------------------------
 * SPI Configuration
 *-----------------------------------------------------------------------------
 */
#if 0			/* The Envirenment is stored in NVRAM and the thermal */ 
#define CONFIG_SPI 1 	/* monitor sensor is not used in u-boot, so we really */ 
#endif			/* have no use for SPI right now.                     */ 


/*-----------------------------------------------------------------------
 * Definitions for initial stack pointer and data area (in DPRAM)
 *----------------------------------------------------------------------*/
#define CFG_INIT_RAM_ADDR	CFG_IMMR
#define	CFG_INIT_RAM_END	0x3000		/* End of used area in DPRAM	*/
#define	CFG_GBL_DATA_SIZE	64  		/* size in bytes reserved for initial data */
#define CFG_GBL_DATA_OFFSET	(CFG_INIT_RAM_END - CFG_GBL_DATA_SIZE)
#define	CFG_INIT_SP_OFFSET	CFG_GBL_DATA_OFFSET

/*-----------------------------------------------------------------------
 * Start addresses for the final memory configuration
 * (Set up by the startup code)
 * note that CFG_SDRAM_BASE _must_ start at 0
 * Note also that the logic that sets CFG_RAMBOOT is platform dependent.
 */
#define	CFG_SDRAM_BASE		0x00000000
#define CFG_FLASH_BASE		0xFF000000
#define CFG_MONITOR_BASE	TEXT_BASE

#if (CFG_MONITOR_BASE < CFG_FLASH_BASE)
  #define CFG_RAMBOOT
#endif

#if defined(DEBUG) || defined (CONFIG_VIDEO_SED13806) || (CONFIG_COMMANDS & CFG_CMD_IDE)
  #define CFG_MONITOR_LEN	(256 << 10)	/* Reserve 256 kB for Monitor	*/
#else
  #define CFG_MONITOR_LEN	(128 << 10)	/* Reserve 128 kB for Monitor	*/
#endif
#define	CFG_MALLOC_LEN		(128 << 10)	/* Reserve 128 kB for malloc()	*/

/*
 * For booting Linux, the board info and command line data
 * have to be in the first 8 MB of memory, since this is
 * the maximum mapped by the Linux kernel during initialization.
 */
#define	CFG_BOOTMAPSZ		(8 << 20)	/* Initial Memory map for Linux	*/

/*-----------------------------------------------------------------------
 * FLASH organization
 *----------------------------------------------------------------------*/
#define CFG_MAX_FLASH_BANKS	1		/* max number of memory banks		*/
#define CFG_MAX_FLASH_SECT	128		/* max number of sectors on one chip	*/

#define CFG_FLASH_ERASE_TOUT	120000		/* Timeout for Flash Erase (in ms)	*/
#define CFG_FLASH_WRITE_TOUT	500		/* Timeout for Flash Write (in ms)	*/

#define CFG_ENV_IS_IN_NVRAM	1

#ifdef CFG_ENV_IS_IN_NVRAM
#  define CFG_ENV_ADDR		0xFA000100
#  define CFG_ENV_SIZE		0x1000
#else
#  define CFG_ENV_IS_IN_FLASH	1
#  define CFG_ENV_SIZE		0x1000  	/* Total size for evironment variables */
#  define CFG_ENV_SECT_SIZE	0x20000 	/* Size of FLASH sector */
#  define CFG_ENV_ADDR	\
	(CFG_FLASH_BASE + CFG_ENV_SECT_SIZE) 	/* Puts ENV in second sector */
#endif /* CFG_ENV_IS_IN_NVRAM */

/*-----------------------------------------------------------------------
 * Cache Configuration
 *----------------------------------------------------------------------*/
#define CFG_CACHELINE_SIZE	16		/* For all MPC8xx CPUs			*/
#if (CONFIG_COMMANDS & CFG_CMD_KGDB)
  #define CFG_CACHELINE_SHIFT	4		/* log base 2 of the above value	*/
#endif

/*-----------------------------------------------------------------------
 * SYPCR - System Protection Control				11-9
 * SYPCR can only be written once after reset!
 *-----------------------------------------------------------------------
 * Software & Bus Monitor Timer max, Bus Monitor enable, SW Watchdog freeze
 */
#define CFG_SYPCR	(SYPCR_SWTC | SYPCR_BMT | SYPCR_BME | SYPCR_SWF | \
			 SYPCR_SWP)

/*-----------------------------------------------------------------------
 * SIUMCR - SIU Module Configuration				11-6
 *-----------------------------------------------------------------------
 * PCMCIA config., multi-function pin tri-state
 */
#define CFG_SIUMCR	(SIUMCR_MLRC10)

/*-----------------------------------------------------------------------
 * TBSCR - Time Base Status and Control				11-26
 *-----------------------------------------------------------------------
 * Clear Reference Interrupt Status, Timebase freezing enabled
 */
#define CFG_TBSCR	(TBSCR_REFA | TBSCR_REFB | TBSCR_TBF | TBSCR_TBE)

/*-----------------------------------------------------------------------
 * PISCR - Periodic Interrupt Status and Control		11-31
 *-----------------------------------------------------------------------
 * Clear Periodic Interrupt Status, Interrupt Timer freezing enabled
 */
#define CFG_PISCR	(PISCR_PS | PISCR_PITF)

/*-----------------------------------------------------------------------
 * PLPRCR - PLL, Low-Power, and Reset Control Register		15-30
 *-----------------------------------------------------------------------
 * Reset PLL lock status sticky bit, timer expired status bit and timer
 * interrupt status bit
 *
 * If this is a 133 MHz CPU, set PLL multiplication factor to 13 (13*10=130)!
 */
/* up to 50 MHz we use a 1:1 clock */
#define CFG_PLPRCR	( (13 << PLPRCR_MFI_SHIFT) )

/*-----------------------------------------------------------------------
 * SCCR - System Clock and reset Control Register		15-27
 *-----------------------------------------------------------------------
 * Set clock output, timebase and RTC source and divider,
 * power management and some other internal clocks
 */
#define SCCR_MASK	SCCR_EBDF11
/* up to 50 MHz we use a 1:1 clock */
#define CFG_SCCR	(SCCR_COM00 | SCCR_TBS | SCCR_RTDIV | SCCR_EBDF01)

/*-----------------------------------------------------------------------
 * PCMCIA stuff
 *-----------------------------------------------------------------------
 *
 */
#define CFG_PCMCIA_MEM_ADDR	(0xE0000000)
#define CFG_PCMCIA_MEM_SIZE	( 64 << 20 )
#define CFG_PCMCIA_DMA_ADDR	(0xE4000000)
#define CFG_PCMCIA_DMA_SIZE	( 64 << 20 )
#define CFG_PCMCIA_ATTRB_ADDR	(0xE8000000)
#define CFG_PCMCIA_ATTRB_SIZE	( 64 << 20 )
#define CFG_PCMCIA_IO_ADDR	(0xEC000000)
#define CFG_PCMCIA_IO_SIZE	( 64 << 20 )

/*-----------------------------------------------------------------------
 * IDE/ATA stuff (Supports IDE harddisk on PCMCIA Adapter)
 *-----------------------------------------------------------------------
 */

#undef	CONFIG_IDE_8xx_PCCARD		/* Use IDE with PC Card	Adapter	*/

#undef	CONFIG_IDE_8xx_DIRECT		/* Direct IDE    not supported	*/
#undef	CONFIG_IDE_LED			/* LED   for ide not supported	*/
#undef	CONFIG_IDE_RESET		/* reset for ide not supported	*/

#define CFG_IDE_MAXBUS		1	/* max. 1 IDE bus		*/
#define CFG_IDE_MAXDEVICE	1	/* max. 1 drive per IDE bus	*/

#define CFG_ATA_IDE0_OFFSET	0x0000

#define CFG_ATA_BASE_ADDR	CFG_PCMCIA_MEM_ADDR

/* Offset for data I/O */
#define CFG_ATA_DATA_OFFSET	(CFG_PCMCIA_MEM_SIZE + 0x320)

/* Offset for normal register accesses */
#define CFG_ATA_REG_OFFSET	(2 * CFG_PCMCIA_MEM_SIZE + 0x320)

/* Offset for alternate registers */
#define CFG_ATA_ALT_OFFSET	0x0100

/*-----------------------------------------------------------------------
 *
 *-----------------------------------------------------------------------
 *
 */

#define CFG_DER	0

/*------------------------------------------------------------------------
 * Init Memory Controller:
 *
 * BR0 and OR0 (FLASH)
 *----------------------------------------------------------------------*/

#define FLASH_BASE_PRELIM	0xFF000000	/* FLASH base */
#define CFG_PRELIM_OR_AM_FL	0xFF000000	/* OR addr mask */

/* FLASH timing: ACS = 0, TRLX = 0, CSNT = 0, SCY = 4, ETHR = 0, BIH = 1 */
#define CFG_OR_TIMING_FLASH (OR_SCY_15_CLK | OR_BI)

#define CFG_OR0_PRELIM	(CFG_PRELIM_OR_AM_FL | CFG_OR_TIMING_FLASH)
#define CFG_BR0_PRELIM	((FLASH_BASE_PRELIM & BR_BA_MSK) | BR_V)

/*------------------------------------------------------------------------
 * BR1 and OR1 (SDRAM)
 *----------------------------------------------------------------------*/

#define SDRAM_BASE_PRELIM	0x00000000	/* SDRAM base	*/
#define	SDRAM_MAX_SIZE		0x04000000	/* max 64 MB */

/* SDRAM timing: GPL5 output to GPL5_A (don't care)	*/
#define CFG_OR_TIMING_SDRAM	0x00000600 	/*use to be 0x00000140*/
#define CFG_PRELIM_OR_AM_SD	0xFC000000	/* OR addr mask */

#define CFG_OR1_PRELIM	(CFG_PRELIM_OR_AM_SD | CFG_OR_TIMING_SDRAM )
#define CFG_BR1_PRELIM	((SDRAM_BASE_PRELIM & BR_BA_MSK) | BR_MS_UPMA | BR_V )

/* BCSR mem setting */
#define	CFG_BR3_PRELIM		0xfa400001
#define CFG_OR3_PRELIM		0xffff8910

/* NVRAM mem setting */
#define	CFG_BR4_PRELIM		0xfa000401
#define CFG_OR4_PRELIM		0xfff80970

/*
 * Memory Periodic Timer Prescaler
 */

/* periodic timer for refresh */
#define CFG_MAMR_PTA		58

/*
 * Refresh clock Prescalar
 */
#define CFG_MPTPR		MPTPR_PTP_DIV8

/*
 * MAMR settings for SDRAM
 */

/* 10 column SDRAM */
#define CFG_MAMR_10COL ((CFG_MAMR_PTA << MAMR_PTA_SHIFT) | MAMR_PTAE \
			| MAMR_G0CLA_A10 | MAMR_GPL_A4DIS)
/* 9 column SDRAM */
#define CFG_MAMR_9COL  ((CFG_MAMR_PTA << MAMR_PTA_SHIFT) | MAMR_PTAE \
			| MAMR_G0CLA_A10 | MAMR_GPL_A4DIS)


/*------------------------------------------------------------------------
 * Internal Definitions
 *
 * Boot Flags
 *----------------------------------------------------------------------*/
#define	BOOTFLAG_COLD		0x01	/* Normal Power-On: Boot from FLASH */
#define BOOTFLAG_WARM		0x02	/* Software reboot		    */


/*------------------------------------------------------------------------
 * BCSRx
 *
 * Board Status and Control Registers
 *
 *----------------------------------------------------------------------*/

#define BCSR0 		0xFA400000
#define BCSR1 		0xFA400001
#define BCSR2 		0xFA400002
#define BCSR3 		0xFA400003
#define BCSR4 		0xFA400004

#define BCSR0_ENMONXCVR	0x01	/* Monitor XVCR Control */
#define BCSR0_ENNVRAM	0x02 	/* CS4# Control */
#define BCSR0_LED5	0x04	/* LED5 control 0='on' 1='off' */
#define BCSR0_LED4	0x08	/* LED4 control 0='on' 1='off' */
#define BCSR0_FULLDPLX	0x10	/* Ethernet XCVR Control */
#define BCSR0_COLTEST	0x20
#define BCSR0_ETHLPBK	0x40
#define BCSR0_ETHEN	0x80

#define BCSR1_PCVCTL7	0x01	/* PC Slot B Control */
#define BCSR1_PCVCTL6	0x02
#define BCSR1_PCVCTL5	0x04
#define BCSR1_PCVCTL4	0x08
#define BCSR1_IPB5SEL	0x10
#define BCSR1_SMCSEL	0x20	/* Monitor XVCR Control */
#define BCSR1_SMCCTS	0x40
#define BCSR1_SMCRTS	0x80

#define BCSR2_FLASHWP	0x02	/* FLASH Control */
#define BCSR2_MIICTL	0x08	/* Fast Ethernet Control */
#define BCSR2_MIIPWRDWN	0x40
#define BCSR2_MIIRST	0x80

#define BCSR3_BWRTC	0x01	/* Real Time Clock Battery */
#define BCSR3_BWNVR	0x02	/* NVRAM Battery */
#define BCSR3_RDY_BSY	0x04	/* Flash Operation */
#define BCSR3_RPXL	0x08	/* Reserved (reads back '1') */
#define BCSR3_D3	0x10	/* Dip Switch settings */
#define BCSR3_D2	0x20
#define BCSR3_D1	0x40
#define BCSR3_D0	0x80

#define BCSR4_SPI_CS_1	0x01	/* SCC control */
#define BCSR4_SPI_CS_0	0x02
#define BCSR4_UNUSED	0x04
#define BCSR4_SCCRI	0x08
#define BCSR4_SCCXCVR	0x10
#define BCSR4_SCCDSR	0x20
#define BCSR4_SCCDTR	0x40
#define BCSR4_SCCSEL	0x80



#define BCSR5_PCVCTL3	0x01	/* PC Slot A Control */
#define BCSR5_PCVCTL2	0x02
#define BCSR5_PCVCTL1	0x04
#define BCSR5_PCVCTL0	0x08
#define BCSR5_IPA5SEL	0x10

#define BCSR14_CPLDREV	0xFF

#define BCSR15_BOARDID	0xFF


#endif	/* __CONFIG_H */
